# Test definitions

This folder contains definitions for integration tests, including integration tests that test the scripts that are referenced in our documentation (`docs_integration` CI pipeline).
